#! /bin/sh
#
# cvs.sh
#
# Copyright (C) 2002 by the KDE authors.
#
# This file contains code from Makefile.common, presumably first
# written by Stephan Kulow.
#

###
### This file defines a shell function for each known target
### and then does a case to call the correct function.
###
### Some recursive make calls have been replaced by shell-function
### calls, particularly subdirs and configure_in.
###




cvs()
{
###
### Handle special autoconf cases first.
###
if test -x /usr/bin/autoconf2.50 ; then
   AUTOCONF="/usr/bin/autoconf2.50"
else
   AUTOCONF="autoconf"
fi


###
### Determine autoconf version and complain about older versions.
###
AUTOCONF_VERSION=`$AUTOCONF --version`
if test "x$AUTOCONF_VERSION" = "xAutoconf version 2.13"; then \
   echo "*** YOU'RE USING AUTOCONF 2.13. You need autoconf 2.5x."
   echo ""
   exit 1
fi 

AUTOMAKE_VERSION=`automake --version | head -1 | sed 's/.*\([0-9][.][0-9]*\) *$/\1/'`
if test "x$AUTOMAKE_VERSION" '!=' "x1.5" ; then
   echo "*** YOU'RE NOT USING AUTOMAKE 1.5."
   echo ""
   exit 1
fi

if grep '$(top_srcdir)/acinclude.m4:' Makefile.am >/dev/null; then \
  echo "*** Creating acinclude.m4"
  rm -f acinclude.m4 configure.files
  $MAKE -f Makefile.am top_srcdir=. acinclude.m4
fi



echo "!!! If you get recursion errors from autoconf, it is advisable to set the"
echo "    environment variable M4 to something including \"--nesting-limit=500\""



if test -r configure.in.in; then \
  rm -f subdirs configure.in
  # old_top_srcdir="$top_srcdir"
  # top_srcdir=.

  echo "*** Creating list of subdirectories"
  $MAKE -f Makefile.am top_srcdir=. subdirs
  # subdirs

  echo "*** Creating configure.in"
  $MAKE -f Makefile.am top_srcdir=. configure.in
  # configure_in

  # top_srcdir="$old_top_srcdir"
fi



echo "*** Creating aclocal.m4"
aclocal



echo "*** Creating configure"
autoconf



if test -r configure.in.in ; then \
  perl -pi -e 'print "if test \"x\$with_fast_perl\" = \"xyes\"
  then\n  perl -i.bak \$ac_aux_dir/conf.change.pl \$CONFIG_STATUS\
  || mv \$CONFIG_STATUS.bak \$CONFIG_STATUS
  \n  rm -f \$CONFIG_STATUS.bak;\nfi\
  \n" if /^\s*chmod\s+.*\+x\s+.*CONFIG_STATUS/;' configure
fi
if grep '} \$ac_kw foo' configure >/dev/null 2>&1; then perl -p -i -e "s/ac_kw foo/ac_kw int foo/" configure; fi


#David's hack for autoconf bug when $INSTALL is set
perl -pi -e 'if (/\[\/\$\]\*. INSTALL=/) { print $_ ; $_ = "\"\") ;;\n"; }' configure
if egrep "^AM_CONFIG_HEADER" configure.in >/dev/null 2>&1; then \
  echo "*** Creating config.h template"
	autoheader
fi



echo "*** Creating Makefile templates"
automake



echo "*** Postprocessing Makefile templates"
perl admin/am_edit



if egrep "^cvs-local:" Makefile.am >/dev/null; then \
  $MAKE -f Makefile.am cvs-local
fi



echo "*** Creating date/time stamp"
touch stamp-h.in



echo "*** Finished"
echo "    Don't forget to run ./configure"
echo "    If you haven't done so in a while, run ./configure --help"
}

dist()
{
if grep -e '$(top_srcdir)/acinclude.m4:' Makefile.am >/dev/null; then
  $MAKE -f Makefile.am top_srcdir=. acinclude.m4
fi
if test -r configure.in.in; then
  # old_top_srcdir="$top_srcdir"
  # top_srcdir=.
  # subdirs
  # configure_in
  # top_srcdir="$old_top_srcdir"
  $MAKE -f Makefile.am top_srcdir=. subdirs configure.in
fi
aclocal
autoheader
automake --foreign --include-deps
perl admin/am_edit
autoconf
if test -r configure.in.in ; then
  perl -pi -e 'print "if test \"x\$with_fast_perl\" = \"xyes\"
  then\n  perl -i.bak \$ac_aux_dir/conf.change.pl \$CONFIG_STATUS
  || mv \$CONFIG_STATUS.bak \$CONFIG_STATUS
  \n  rm -f \$CONFIG_STATUS.bak;\nfi
  \n" if /^\s*chmod\s+.*\+x\s+.*CONFIG_STATUS/;' configure
fi
touch stamp-h.in
if grep -e "^cvs-local:" Makefile.am >/dev/null; then
  $MAKE -f Makefile.am cvs-local
fi
if grep "ac_kw foo" configure >/dev/null 2>&1; then perl -p -i -e "s/ac_kw foo/ac_kw int foo/" configure; fi
if test -d po; then
 LIST=`find ./po -name "*.po"`
 for i in $LIST; do
  file2=`echo $i | sed -e "s#\.po#\.gmo#"`
  msgfmt -o $file2 $i || touch $file2
 done
fi
if grep -e "^cvs-dist-local:" Makefile.am >/dev/null; then
  $MAKE -f Makefile.am cvs-dist-local
fi
}

configure_in()
{
rm -f configure.in configure.in.new
> configure.in.new
kde_use_qt_param=
test -f configure.files && \
   cat `cat configure.files | egrep -v "^configure.in.bot"` >> configure.in.new
echo "KDE_CREATE_SUBDIRSLIST" >> configure.in.new
echo "AC_OUTPUT( \\" >> configure.in.new
mfs=`find . -type d -print | fgrep -v "/." | sed -e "s#\./##" -e "/^debian/d" | sort`
for i in $mfs; do
  topleveldir=`echo $i| sed -e "s#/.*##"`
  if test -f $topleveldir/configure.in; then
	continue
  fi
  if test ! -f $i/Makefile.am; then
	continue
  fi
  if test -s inst-apps; then
    if test -z "`grep \"^$topleveldir\" inst-apps`"; then
	continue
    fi
  fi
  echo "$i/Makefile \\" >> configure.in.new
done
test -f configure.files && egrep '^dnl AC_OUTPUT\(.*\)' `cat configure.files` | sed -e "s#^.*dnl AC_OUTPUT(\(.*\))#\1 \\\\#" >> configure.in.new
echo ")" >> configure.in.new
modulename=
if test -f configure.in.in; then
   if head -2 configure.in.in | egrep "^#MIN_CONFIG\(.*\)$" > /dev/null; then
      line=`egrep "^#MIN_CONFIG\(" configure.in.in`
      if test -n "$line"; then
	  kde_use_qt_param=`echo $line | sed -e "s/#MIN_CONFIG(\(.*\))/\1/"`
      fi
   fi
   if head -2 configure.in.in | egrep "^#MIN_CONFI(G|G\(.*\))$" > /dev/null; then
      line=`egrep "^AM_INIT_AUTOMAKE\(" configure.in.in`
      if test -n "$line"; then
	  modulename=`echo $line | sed -e "s#AM_INIT_AUTOMAKE(\([^,]*\),.*#\1#"`
	  VERSION=`echo $line | sed -e "s#AM_INIT_AUTOMAKE([^,]*, *\([^)]*\)).*#\1#"`
       fi
      sed -e "s#AM_INIT_AUTOMAKE([^@].*#dnl PACKAGE set before#" \
          configure.in.new > configure.in && mv configure.in configure.in.new
   fi
fi
if test -z "$modulename" || test "$modulename" = "@MODULENAME@"; then
   modulename=`pwd`; modulename=`basename $modulename`
fi
if test -z "$VERSION" || test "$VERSION" = "@VERSION@"; then
     VERSION="\"3.0\""
fi
if test -n "$kde_use_qt_param"; then
      sed -e "s#^dnl KDE_USE_QT#KDE_USE_QT($kde_use_qt_param)#" \
      	configure.in.new > configure.in && mv configure.in configure.in.new
fi
sed -e "s#@MODULENAME@#$modulename#" configure.in.new |
	sed -e "s#@VERSION@#$VERSION#" > configure.in
if test -f configure.in.bot ; then cat configure.in.bot >> configure.in ; fi
rm -f configure.in.new
}

configure_files()
{
admindir=NO
for i in . .. ../.. ../../..; do
  if test -x $i/admin; then admindir=$i/admin; break; fi
done
rm -rf configure.files
if test -f configure.in.in && head -2 configure.in.in | egrep "^#MIN_CONFI(G|G\(.*\))$" > /dev/null; then
	echo $admindir/configure.in.min >> configure.files
fi
test -f configure.in.in && echo configure.in.in >> configure.files
list=`find . -name "configure.in.in" | sort`
for i in $list; do if test -f $i && test ! `dirname $i` = "." ; then
  echo $i >> configure.files
fi; done
if test -f configure.in.mid ; then echo configure.in.mid >> configure.files ; fi
if test -f configure.in.bot ; then echo configure.in.bot >> configure.files ; fi
}

subdirs()
{
files=`ls -1 | sort`
dirs=
lib_dirs=
first_dirs=
last_dirs=
compilefirst=`grep '^COMPILE_FIRST[ ]*=' Makefile.am |
	sed -e 's#^COMPILE_FIRST[ ]*=[ ]*#|#' | sed -e 's#$#|#' | sed -e 's# #|#g'`
compilelast=`grep '^COMPILE_LAST[ ]*=' Makefile.am |
	sed -e 's#^COMPILE_LAST[ ]*=[ ]*#|#' | sed -e 's#$#|#' | sed -e 's# #|#g'`
for i in $files; do if test -d $i; then
    if test -f $i/Makefile.am; then
	if echo $compilefirst | grep "|$i|" >/dev/null; then
		first_dirs="$first_dirs $i"
	elif echo $compilelast | grep "|$i|" >/dev/null; then
		last_dirs="$last_dirs $i"
	else dirs="$dirs $i"
	fi
     fi
   fi
done
rm -f _SUBDIRS
for i in $dirs; do
echo $i >> ./_SUBDIRS
done
if test -r subdirs && diff subdirs _SUBDIRS > /dev/null; then
  rm -f _SUBDIRS
fi
test -r _SUBDIRS && mv _SUBDIRS subdirs || true
}

###
### Main
###

case "x$1" in
  xcvs              ) cvs ;;
  xdist             ) dist ;;
  xconfigure.in     ) configure_in ;;
  xconfigure.files  ) configure_files ;;
  xsubdirs          ) subdirs ;;
  * ) echo "Usage: cvs.sh <cvs|dist|configure.in|configure.files>" 
      echo "Usage: anything but $1"
      exit 1 ;;
esac

